From 5dfbce18563df7d6cdb4a400a1c12a9f485449b8 Mon Sep 17 00:00:00 2001
From: DJj123dj <80536295+DJj123dj@users.noreply.github.com>
Date: Wed, 27 Mar 2024 14:22:35 +0100
Subject: [PATCH] v3.5.4 push 1
---
.github/SECURITY.md | 9 +--
README.md | 72 ++++++++---------
config.json | 2 +-
core/checker.js | 2 +-
core/statsManager.js | 6 +-
core/transcriptSystem/embeds.js | 12 +--
core/transcriptSystem/manager.js | 12 +--
index.js | 2 +-
language/arabic.json | 2 +-
language/custom.json | 2 +-
language/czech.json | 2 +-
language/danish.json | 4 +-
language/dutch.json | 4 +-
language/english.json | 2 +-
language/german.json | 4 +-
language/greek.json | 2 +-
language/hungarian.json | 2 +-
language/indonesian.json | 2 +-
language/italian.json | 4 +-
language/kurdish.json | 135 +++++++++++++++++++++++++++++++
language/norwegian.json | 4 +-
language/polish.json | 4 +-
language/portuguese.json | 4 +-
language/romanian.json | 2 +-
language/russian.json | 4 +-
language/slovenian.json | 4 +-
language/spanish.json | 4 +-
language/thai.json | 4 +-
language/turkish.json | 4 +-
language/ukrainian.json | 4 +-
package.json | 4 +-
31 files changed, 227 insertions(+), 97 deletions(-)
create mode 100644 language/kurdish.json
diff --git a/.github/SECURITY.md b/.github/SECURITY.md
index 9f12cce..f77feb0 100644
--- a/.github/SECURITY.md
+++ b/.github/SECURITY.md
@@ -9,11 +9,10 @@ Below, you can find a list with the status of every open ticket version. This li
| Version | Supported | Until |
|-----------|-----------|-----------------------------|
-| 3.5.3 | ✅ | |
-| 3.5.2 | ✅ | April 2024 |
-| 3.5.1 | 🟧 | Next Update |
-| 3.5.0 | 🟧 | Next Update |
-| < 3.5.0 | ❌ | |
+| 3.5.4 | ✅ | |
+| 3.5.3 | ✅ | May 2024 |
+| 3.5.2 | 🟧 | Next Update |
+| < 3.5.2 | ❌ | |
## Reporting a Vulnerability
diff --git a/README.md b/README.md
index d3d4ed9..819bed8 100644
--- a/README.md
+++ b/README.md
@@ -5,10 +5,10 @@ There will be massive improvements for more stability & features! But the best p
-[](https://discord.com/invite/26vT9wt3n3) [](https://github.com/DJj123dj/open-ticket/releases/tag/v3.5.3) []() [](https://github.com/DJj123dj/open-ticket/blob/main/LICENSE) [](https://docs.openticket.dj-dj.be)
+[](https://discord.com/invite/26vT9wt3n3) [](https://github.com/DJj123dj/open-ticket/releases/tag/v3.5.4) []() [](https://github.com/DJj123dj/open-ticket/blob/main/LICENSE) [](https://docs.openticket.dj-dj.be)
### Open Ticket
-Open Ticket is the most customisable discord ticket bot that you will ever find! There are more than 150 options to customise in the config! This includes html transcripts, unlimited amount of tickets, custom embeds & more! Did you know that even the html transcripts are highly customisable? Don't wait and check it out! If you're having trouble setting the bot up, feel free to join our support server and we will help you further!
+Open Ticket is the most customisable discord ticket bot that you will ever find! There are more than 150 options to customise in the config! This includes html transcripts, unlimited tickets, custom embeds & more! Did you know that even the html transcripts are highly customisable? Don't wait and check it out! If you're having trouble setting the bot up, feel free to join our support server and we will help you further!
Take a look at all the features and discover the possibilities!
### [Visit the Documentation!](https://docs.openticket.dj-dj.be/quick-start)
@@ -16,25 +16,17 @@ Take a look at all the features and discover the possibilities!
## Features
- **🎉 advanced html transcripts!**
- 🔒 close, ❌ delete & ✅ re-open tickets
-- 🇬🇧 translation in 19 different languages
+- 🇬🇧 translation in 22 different languages
- 📄 very advanced customisation
- 🆗 buttons or 🔽 dropdowns!
-- 🆒 plugins
-- ∞ unlimited tickets & unlimited messages
+- 🆒 custom plugins
+- ∞ unlimited tickets & embeds
- ➕➖ add/remove users from a ticket
- 📊 ticket, user & global staticstics
- /slash & text commands
-
-
- But wait, there are even more features! Click here to discover!
-
-
- - fully customisable embeds & buttons
- - close tickets with reason
- - reaction roles (or verification system)
- - discord interaction buttons
- - discord.js v14
-
+- 📥 reaction roles & url buttons
+- 🖥️ discord.js v14 & axios
+- 🎛️ latest discord integration
## preview
@@ -54,31 +46,33 @@ Take a look at all the features and discover the possibilities!
|Designer |vuur_draak |
### Translators
-|Language |Maintainer (discord name) |Status |
-|-------------------|--------------------------|--------------------------------|
-|English |djj123dj |🟢 Up To Date |
-|Dutch |djj123dj |🟢 Up To Date |
-|French |sankedev & tostam |🟢 Up To Date |
-|Romanian |sankedev |🟢 Up To Date |
-|Spanish |redactado & josuens |🟢 Up To Date |
-|German |david.3 |🟢 Up To Date |
-|Italian |maurizio26 |🟢 Up To Date |
-|Czech |spyeye_ |🟢 Up To Date |
-|Arabic |deqressing |🟢 Up To Date |
-|Danish |.the_gamer |🟢 Up To Date |
-|Portuguese |quiradon |🔴 Outdated |
-|Russian |apexo & ander |🟢 Up To Date |
-|Ukrainian |ander |🟢 Up To Date |
-|Turkish |Hydra#0009 |🔴 Outdated |
-|Polish |mkevas |🟢 Up To Date |
-|Slovenian |n1kkec |🔴 Outdated |
-|Thai |modshd |🟢 Up To Date |
-|Norwegian |noonenook |🟢 Up To Date |
-|Greek |stefanos__. |🔴 Outdated |
-|Indonesian |erxg |🟢 Up To Date |
+|Language |Maintainer (discord name) |Status |
+|-------------------|--------------------------|---------------|
+|English |djj123dj |🟢 Up To Date |
+|Dutch |djj123dj |🟢 Up To Date |
+|French |sankedev & tostam |🟢 Up To Date |
+|Romanian |sankedev |🟢 Up To Date |
+|Spanish |redactado & josuens |🟢 Up To Date |
+|German |david.3 |🟢 Up To Date |
+|Italian |maurizio26 |🟢 Up To Date |
+|Czech |spyeye_ |🟢 Up To Date |
+|Arabic |deqressing |🟢 Up To Date |
+|Danish |.the_gamer |🟢 Up To Date |
+|Portuguese |quiradon |🔴 Outdated |
+|Russian |apexo & ander |🟢 Up To Date |
+|Ukrainian |ander |🟢 Up To Date |
+|Turkish |Hydra#0009 |🔴 Outdated |
+|Polish |mkevas |🟢 Up To Date |
+|Slovenian |n1kkec |🔴 Outdated |
+|Thai |modshd |🟢 Up To Date |
+|Norwegian |noonenook |🟢 Up To Date |
+|Greek |stefanos__. |🔴 Outdated |
+|Indonesian |erxg |🟢 Up To Date |
+|Kurdish |raze.hama |🟢 Up To Date |
+|Hungarian |Snowy |🔴 Outdated |
## links
-current version: _v3.5.3_
+current version: _v3.5.4_
changelog: [click here](https://otgithub.dj-dj.be/releases)
documentation: [click here](https://docs.openticket.dj-dj.be/quick-start)
diff --git a/config.json b/config.json
index 4a2e3b6..cf6362f 100644
--- a/config.json
+++ b/config.json
@@ -111,7 +111,7 @@
"dropdown":false,
"enableFooter":false,
- "footer":"Open Ticket v3.5.3 - I'm a footer!",
+ "footer":"Open Ticket v3.5.4 - I'm a footer!",
"enableFooterImage":false,
"footerImage":"https://www.example.com/catmemes/cat.png",
diff --git a/core/checker.js b/core/checker.js
index 4559152..7b90eac 100644
--- a/core/checker.js
+++ b/core/checker.js
@@ -427,7 +427,7 @@ exports.checker = async () => {
checkType(config.languageFile,"string","languagefile")
const lf = config.languageFile
- if (!lf.startsWith("custom") && !lf.startsWith("english") && !lf.startsWith("dutch") && !lf.startsWith("romanian") && !lf.startsWith("german") && !lf.startsWith("arabic") && !lf.startsWith("spanish") && !lf.startsWith("portuguese") && !lf.startsWith("french") && !lf.startsWith("italian") && !lf.startsWith("czech") && !lf.startsWith("danish") && !lf.startsWith("russian") && !lf.startsWith("turkish") && !lf.startsWith("polish") && !lf.startsWith("slovenian") && !lf.startsWith("thai") && !lf.startsWith("norwegian") && !lf.startsWith("greek") && !lf.startsWith("ukrainian") && !lf.startsWith("hungarian") && !lf.startsWith("indonesian")){
+ if (!lf.startsWith("custom") && !lf.startsWith("english") && !lf.startsWith("dutch") && !lf.startsWith("romanian") && !lf.startsWith("german") && !lf.startsWith("arabic") && !lf.startsWith("spanish") && !lf.startsWith("portuguese") && !lf.startsWith("french") && !lf.startsWith("italian") && !lf.startsWith("czech") && !lf.startsWith("danish") && !lf.startsWith("russian") && !lf.startsWith("turkish") && !lf.startsWith("polish") && !lf.startsWith("slovenian") && !lf.startsWith("thai") && !lf.startsWith("norwegian") && !lf.startsWith("greek") && !lf.startsWith("ukrainian") && !lf.startsWith("hungarian") && !lf.startsWith("indonesian") && !lf.startsWith("kurdish")){
createError("'languagefile' | invalid language, more info in the wiki")
}
diff --git a/core/statsManager.js b/core/statsManager.js
index c18ec7d..7a2acf8 100644
--- a/core/statsManager.js
+++ b/core/statsManager.js
@@ -220,7 +220,7 @@ const getTicketStats = async (guild,channelid) => {
/**@type {TextChannel|undefined} */
const channel = guild.channels.cache.find((c) => c.id == channelid)
const messageAmount = (channel) ? (await getmessages(channel,5000)).length : 0
- const participants = (channel) ? channel.members.map((m) => m.user.username) : []
+ const participants = (channel) ? channel.members.map((m) => "<@"+m.user.id+">") : []
//saved data
const createdAt = getStats("ticket","CREATED_AT",channelid)
@@ -228,7 +228,7 @@ const getTicketStats = async (guild,channelid) => {
const TEMPcreatedBy = getStats("ticket","CREATED_BY",channelid)
const TEMPcreatedByUser = (TEMPcreatedBy) ? guild.members.cache.find((m) => m.id == TEMPcreatedBy) : undefined
- const createdBy = (TEMPcreatedByUser) ? TEMPcreatedByUser.user.username : "an unknown person 😄"
+ const createdBy = (TEMPcreatedByUser) ? "<@"+TEMPcreatedByUser.user.id+">" : "an unknown person 😄"
return {
createdAt: (typeof createdAt == "undefined") ? new Date().getTime() : createdAt,
@@ -316,7 +316,7 @@ const createTicketStatsEmbed = async (guild,channelid) => {
const sentences = [
`${l.stats.ticketCreatedOn}: `,
- `${l.stats.ticketCreatedBy}: \`${stats.createdBy}\``,
+ `${l.stats.ticketCreatedBy}: ${stats.createdBy}`,
`${l.stats.messagesSent}: \`${stats.messageAmount}\``,
`${l.stats.status}: ${newStatus}`
]
diff --git a/core/transcriptSystem/manager.js b/core/transcriptSystem/manager.js
index 8ba7e4c..28d1c1c 100644
--- a/core/transcriptSystem/manager.js
+++ b/core/transcriptSystem/manager.js
@@ -114,7 +114,7 @@ module.exports = async (messages,guild,channel,user,reason) => {
tc.send({embeds:[errembed],files:[attachment]})
}
if (tsconfig.sendTranscripts.enableDM && user){
- const embed = tsembeds.tsready(chName,chId,null,user)
+ const embed = tsembeds.tsready(chName,null,user,ticketopener)
try {
ticketopener.send({embeds:[embed],files:[attachment]})
}catch{}
@@ -151,12 +151,12 @@ module.exports = async (messages,guild,channel,user,reason) => {
//ready
setTimeout(() => {
if (msg){
- msg.edit({embeds:[tsembeds.tsready(chName,chId,url,user)]})
+ msg.edit({embeds:[tsembeds.tsready(chName,url,user,ticketopener)]})
}
if (tsconfig.sendTranscripts.enableDM){
if (!user) return
- const embed = tsembeds.tsready(chName,chId,url,user)
+ const embed = tsembeds.tsready(chName,url,user,ticketopener)
try {
ticketopener.send({embeds:[embed]})
}catch{}
@@ -174,7 +174,7 @@ module.exports = async (messages,guild,channel,user,reason) => {
tc.send({embeds:[errembed],files:[attachment]})
}
if (tsconfig.sendTranscripts.enableDM && user){
- const embed = tsembeds.tsready(chName,chId,null,user)
+ const embed = tsembeds.tsready(chName,null,user,ticketopener)
try {
ticketopener.send({embeds:[embed],files:[attachment]})
}catch{}
@@ -182,7 +182,7 @@ module.exports = async (messages,guild,channel,user,reason) => {
}
}else{
const attachment = await require("./oldTranscript").createTranscript(messages,channel)
- const embed = tsembeds.tsready(chName,chId,false,user)
+ const embed = tsembeds.tsready(chName,null,user,ticketopener)
if (tsconfig.sendTranscripts.enableChannel){
/**@type {discord.TextChannel|undefined} */
@@ -192,7 +192,7 @@ module.exports = async (messages,guild,channel,user,reason) => {
tc.send({embeds:[embed],files:[attachment]})
}
if (tsconfig.sendTranscripts.enableDM && user){
- const embed = tsembeds.tsready(chName,chId,null,user)
+ const embed = tsembeds.tsready(chName,null,user,ticketopener)
try {
ticketopener.send({embeds:[embed],files:[attachment]})
}catch{}
diff --git a/index.js b/index.js
index a9bea81..6cbe24f 100644
--- a/index.js
+++ b/index.js
@@ -25,7 +25,7 @@
INFORMATION:
============
- Open Ticket v3.5.3 - © DJdj Development
+ Open Ticket v3.5.4 - © DJdj Development
discord: https://discord.dj-dj.be
website: https://www.dj-dj.be
diff --git a/language/arabic.json b/language/arabic.json
index f963e08..2a2664d 100644
--- a/language/arabic.json
+++ b/language/arabic.json
@@ -1,6 +1,6 @@
{
"_CREDITS":"deqressing",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors": {
"missingArgsTitle": "قيمة غير صالحة!",
diff --git a/language/custom.json b/language/custom.json
index 14fe207..c8ce798 100644
--- a/language/custom.json
+++ b/language/custom.json
@@ -1,6 +1,6 @@
{
"_CREDITS":"DJdj Development",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Invalid Arguments!",
diff --git a/language/czech.json b/language/czech.json
index 911be90..edf8e81 100644
--- a/language/czech.json
+++ b/language/czech.json
@@ -1,6 +1,6 @@
{
"_CREDITS":"spyeye_",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Neplatný Argument!",
diff --git a/language/danish.json b/language/danish.json
index 192dd0f..d640841 100644
--- a/language/danish.json
+++ b/language/danish.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"the_gamer#5095",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":".the_gamer",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors": {
"missingArgsTitle": "Ugyldigt Argument!",
diff --git a/language/dutch.json b/language/dutch.json
index 9938f7f..d48f9cd 100644
--- a/language/dutch.json
+++ b/language/dutch.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"DJj123dj#1706",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"djj123dj",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Onjuiste parameters!",
diff --git a/language/english.json b/language/english.json
index a096d8d..8414643 100644
--- a/language/english.json
+++ b/language/english.json
@@ -1,6 +1,6 @@
{
"_CREDITS":"DJdj Development",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Invalid Arguments!",
diff --git a/language/german.json b/language/german.json
index 628927e..0141d4e 100644
--- a/language/german.json
+++ b/language/german.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"david.#8276 ",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"david.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Ungültiges Argument!",
diff --git a/language/greek.json b/language/greek.json
index 8adfdfc..c1f6e45 100644
--- a/language/greek.json
+++ b/language/greek.json
@@ -1,6 +1,6 @@
{
"_CREDITS":"ꙅoᴎɒᎸɘƚꙅ#3744",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Invalid Arguments!",
diff --git a/language/hungarian.json b/language/hungarian.json
index 13ce00d..84811df 100644
--- a/language/hungarian.json
+++ b/language/hungarian.json
@@ -1,6 +1,6 @@
{
"_CREDITS":"Snowy",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Hibás paraméterek!",
diff --git a/language/indonesian.json b/language/indonesian.json
index 7cc0fb5..72a46e7 100644
--- a/language/indonesian.json
+++ b/language/indonesian.json
@@ -1,6 +1,6 @@
{
"_CREDITS":"erxg",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Argumen tidak valid!",
diff --git a/language/italian.json b/language/italian.json
index 421381b..cf8dde9 100644
--- a/language/italian.json
+++ b/language/italian.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"Maurizio#0268",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"maurizio26",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Argomenti non validi!",
diff --git a/language/kurdish.json b/language/kurdish.json
new file mode 100644
index 0000000..049158d
--- /dev/null
+++ b/language/kurdish.json
@@ -0,0 +1,135 @@
+{
+ "_CREDITS":"raze.hama",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
+
+ "errors":{
+ "missingArgsTitle":"ئهوهی ههڵتبژاردوه نادروسته",
+ "missingArgsDescription":"ئهوهی ههڵتبژاردوه ناردوسته",
+ "noPermsTitle":"هیچ مۆڵەتێک نییە!",
+ "noPermsDescription":"پێویستت بە مۆڵەتی ئهدمین سترهیتهر هەیە یان دهبێت لە لیستی ڕۆڵە ڕێگەپێدراوەکاندا بیت!",
+ "noPermsDelete":"تەنها ئەدمینەکان دەتوانن بلیت بسڕنەوە!",
+ "chooseFromListTitle":"ناسنامەی نادروست",
+ "chooseFromListDescription":"یەکێک لەم ناسنامانهی خوارەوە هەڵبژێرە:",
+ "boterror":"هەڵەی بۆت!",
+ "notInTicketTitle":"تۆ لەناو بلیتدا نیت!",
+ "notInTicketDescription":"ئەم فەرمانە لە دەرەوەی بلیت کارناکات!",
+ "ticketDoesntExist":"ئەم بلیتە ئیتر بوونی نییە!",
+ "roleDoesntExist":"ئیتر ئەم ڕۆڵە بوونی نییە!",
+ "anotherOption":"ئەم بژاردەیە بلیت نیە بەڵکو جۆرێکی ترە !",
+ "maxAmountTitle":"تۆگهشتی به زۆرترین",
+ "maxAmountDescription":"گەیشتووی بە زۆرترین ژمارەی بلیت کە ڕێگەپێدراوە\nبۆیە ناتوانیت نوێ دروست بکەیت",
+ "somethingWentWrong":"**شتێک بە هەڵەدا چووە **\n تکایە جارێکی تر هەوڵبدەرەوە"
+ },
+ "commands":{
+ "userAddedTitle":"زیادكرا {0} بۆ ئهم بلیته",
+ "userRemovedTitle":"لابرا{0} لهم بلیته ",
+ "renameTitle":"ناوەکەی گۆڕی بۆ... {0}!",
+ "closeTitle":"ئەم بلیتەی داخست!",
+ "deleteTitle":"سڕینەوەی ئەم بلیتە...",
+ "reopenTitle":"ئەم بلیتە دووبارە کردەوە!",
+
+ "claimTitle":"ئەم بلیتە بانگەشەی ئەوە دەکرێت کە... {0}",
+ "unclaimTitle":"ئیتر ئەم بلیتە داوای ناکرێت!",
+ "changeTitle":"جۆری بلیت گۆڕی بۆ... {0}!",
+
+ "statsTitle":"لێرەدا ئامارەکان بۆ... {0}!",
+ "autocloseTitle":"ئەم بلیتە بە شێوەیەکی ئۆتۆماتیکی دادەخرێت دوای...{0}!",
+ "autocloseRejectTitle":"ئەم بلیتە چیتر بە شێوەیەکی ئۆتۆماتیکی داناخرێت!",
+ "autocloseWarn":"ئەمەش تەنها کاریگەری لەسەر بلیتی ناچالاک هەیە!",
+
+ "goToTicket":"بڕۆ بۆ بلیت",
+ "ticketWarning":"جێگیرکردنەکە لە نامەکەی خوارەوەدایە!",
+ "maxTicketWarning":"**ئاگاداری:** _تەنها دەتوانیت لە یەک کاتدا {0} بلیت(ەکان) دروست بکەیت!_"
+ },
+ "helpMenu":{
+ "title":"فەرمانە بەردەستەکان:",
+ "header1":"**Go to {0} to create a ticket!**\n\n",
+ "header2":"**فەرمانەکە جێبەجێ بکە `/new` or `/ticket` بۆ دروستکردنی بلیت!**\n\n",
+
+ "msgCmd":"(تەنها ئەدمینەکان)",
+ "renameCmd":"ناوی بلیتهكه بگۆره",
+ "closeCmd":"بلیتێک دابخە.",
+ "deleteCmd":"بلیتێک بسڕەوە.",
+ "addCmd":"بەکارهێنەرێک زیاد بکە بۆ بلیتەکە.",
+ "removeCmd":"بەکارهێنەرێک لە بلیتەکە دەربهێنە.",
+ "reopenCmd":"دووبارە بلیتێک بکەرەوە دوای داخستنی.",
+ "changeCmd":"گۆڕینی جۆری بلیت.",
+ "claimCmd":"داوای بلیتێک بکە.",
+ "unclaimCmd":"داوای بلیتێک وەربگرە.",
+ "statsCmd":"بینینی ئاماری بلیتەکان.",
+ "autocloseCmd":"تایمەر دابنێ بۆ ئەوەی بلیتەکە بە شێوەیەکی ئۆتۆماتیکی دابخات"
+ },
+ "buttons":{
+ "close":"داخستنی بلیت",
+ "delete":"سڕینەوەی بلیت",
+ "reopen":"دوباره بلیتهكه بكهرهوه",
+ "closeWithReason":"هۆكارێك بنوسه بۆ داخستنی بلیتهكه"
+ },
+ "messages":{
+ "closedDescription":"ئێستا تەنها ئەدمینەکان دەتوانن لەم بلیتەدا قسە بکەن!\n\n*بۆ سڕینەوە یان دووبارە کردنەوەی ئەم بلیتە کلیک لەسەر دوگمەی خوارەوە بکە!*",
+ "createdTitle":"بلیت دروستکراوە!",
+ "createdDescription":"بلیتەکەت دروست کراوە، دەتوانیت بە پینگێک دەستنیشان بکەیت!",
+
+ "newTicketDmTitle":"بلیتی نوێ!",
+ "closedTicketDmTitle":"بلیت داخراوە!",
+ "deletedTicketDmTitle":"بلیت سڕاوەتەوە!",
+ "closedTicketDmDescription":"بلیتەکەت داخراوە!",
+ "deletedTicketDmDescription":"بلیتەکەت سڕاوەتەوە!",
+ "reopenTicketDmTitle":"بلیت دووبارە کرایەوە!",
+ "reopenTicketDmDescription":"بلیتەکەت دەکرێتەوە!",
+
+ "chooseCategory":"پۆلێک هەڵبژێرە:",
+ "gettingdeleted":"بلیتەکە خەریکە دەسڕدرێتەوە...",
+
+ "none":"هیچ",
+ "reason":"هۆكار",
+ "createdat":"دروستکراوە لە",
+ "openedby":"لەلایەن...",
+ "deletedby":"سڕاوەتەوە لەلایەن",
+ "closedby":"داخراوە لەلایەن",
+
+ "modalreason":"هۆکاری داخستنی ئەم بلیتە چییە؟",
+ "chooseATicket": "بلیتێک هەڵبژێرە"
+ },
+ "transcripts":{
+ "title":"گواستنهوه",
+ "processed":"ئەم گواستنهوهیه خەریکە پرۆسێس دەکرێت",
+ "wait":"تكایه چاوهڕێبه!",
+ "estimated":"کاتی مەزەندەکراو",
+ "available":" گواستنهوهكه لێرەدا بەردەستە"
+ },
+ "stats":{
+ "globalTitle":"ئاماری جیهانی",
+ "ticketTitle":"ئاماری بلیت بۆ {0}",
+ "userTitle":"ئاماری بەکارهێنەر بۆ {0}",
+ "systemTitle":"ئاماری سیستەم",
+ "versionTitle":"وەشانی بۆت",
+
+ "ticketsCreated":"بلیتەکان دروستکراون",
+ "ticketsClosed":"بلیتەکان داخراون",
+ "ticketsDeleted":"بلیتەکان سڕاونەتەوە",
+ "ticketsReopened":"بلیتەکان کرایەوە",
+ "ticketsAutoclosed":"بلیتەکان بە شێوەیەکی ئۆتۆماتیکی داخراون",
+ "transcriptsCreated":"گواستنهوه دروستکراون",
+ "startupDate":"بەرواری دەستپێکردن",
+ "latestUpdate":"نوێترین نوێکردنەوە",
+ "ticketCreatedOn":"بلیت دروستکراوە لەسەر",
+ "ticketCreatedBy":"بلیت دروستکراوە لەلایەن...",
+ "messagesSent":"پەیامەکان نێردراوە",
+ "status":"دۆخ",
+ "participants":"بەشداربووان",
+ "role":"ئەرک",
+
+ "switches":{
+ "globalAdmin":"بەڕێوەبەری جیهانی",
+ "ticketAdmin":"ئەدمینی بلیتەکان",
+ "member":"ئەندام",
+ "open":"کردنەوە",
+ "reopened":"دووبارە کرایەوە",
+ "closed":"داخراوە",
+ "autoclosed":"ئۆتۆماتیکی داخراوە"
+ },
+
+ "errorUserNotFound":"ئەم بەکارهێنەرە لە بنکەدراوەی ئامارەکاندا نادۆزرێتەوە!"
+ }
+}
\ No newline at end of file
diff --git a/language/norwegian.json b/language/norwegian.json
index f0229fa..7d44a41 100644
--- a/language/norwegian.json
+++ b/language/norwegian.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"NoOneNook#0266",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"noonenook",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Ugyldige argumenter!",
diff --git a/language/polish.json b/language/polish.json
index 5145c2e..3e314b3 100644
--- a/language/polish.json
+++ b/language/polish.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"MKevas#8311",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"mkevas",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Nieprawidłowe argumenty!",
diff --git a/language/portuguese.json b/language/portuguese.json
index 0ba4074..5c17b82 100644
--- a/language/portuguese.json
+++ b/language/portuguese.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"QuirAddon#9778",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"quiradon",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Argumentos inválidos!",
diff --git a/language/romanian.json b/language/romanian.json
index f7f07b3..9999040 100644
--- a/language/romanian.json
+++ b/language/romanian.json
@@ -1,6 +1,6 @@
{
"_CREDITS":"Sanke#6086",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Argumente Invalide",
diff --git a/language/russian.json b/language/russian.json
index 9ee035c..bfd96f0 100644
--- a/language/russian.json
+++ b/language/russian.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"Apexo#0723",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"apexo & ander",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Неверные аргументы!",
diff --git a/language/slovenian.json b/language/slovenian.json
index 0f6da75..4470a7e 100644
--- a/language/slovenian.json
+++ b/language/slovenian.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"n1kkec#5341",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"n1kkec",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Napačen argument!",
diff --git a/language/spanish.json b/language/spanish.json
index 587abdb..02a19a7 100644
--- a/language/spanish.json
+++ b/language/spanish.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"Redactado#1673 & josuens14#5267",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"redactado & josuens",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"¡Argumentos inválidos!",
diff --git a/language/thai.json b/language/thai.json
index 5741548..88b7bba 100644
--- a/language/thai.json
+++ b/language/thai.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"Mods HD#0661",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"modshd",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"อาร์กิวเมนต์ไม่ถูกต้อง!",
diff --git a/language/turkish.json b/language/turkish.json
index 46941ae..2de66a2 100644
--- a/language/turkish.json
+++ b/language/turkish.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"Hydrâelčhâvø#1575",
- "_INFO":"This file is a translation for open ticket 3.5.3",
+ "_CREDITS":"Hydra#0009",
+ "_INFO":"This file is a translation for open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Geçersiz argümanlar!",
diff --git a/language/ukrainian.json b/language/ukrainian.json
index eb32f3f..1ad7754 100644
--- a/language/ukrainian.json
+++ b/language/ukrainian.json
@@ -1,6 +1,6 @@
{
- "_CREDITS":"Anderskiy#4093",
- "_INFO":"Цей файл є перекладом для open ticket 3.5.3",
+ "_CREDITS":"ander",
+ "_INFO":"Цей файл є перекладом для open ticket 3.5.4",
"errors":{
"missingArgsTitle":"Невірні аргументи!",
diff --git a/package.json b/package.json
index cea9a1c..d7368fe 100644
--- a/package.json
+++ b/package.json
@@ -1,7 +1,7 @@
{
"name": "open-ticket",
- "version": "3.5.3",
- "description": "This is an open-source discord ticket bot, you can configure it and it comes with cool features like a transcript.",
+ "version": "3.5.4",
+ "description": "TThe most advanced open-source discord ticket bot with HTML transcripts and plugins! It uses discord.js v14 & no database required!",
"main": "index.js",
"scripts": {
"start": "node index.js",
diff --git a/core/transcriptSystem/embeds.js b/core/transcriptSystem/embeds.js
index 48f0b54..d2ec977 100644
--- a/core/transcriptSystem/embeds.js
+++ b/core/transcriptSystem/embeds.js
@@ -34,17 +34,19 @@ exports.beingprocessed = (name,id,rawprocesstime,user) => {
/**
*
* @param {String} name
* @param {String} id
* @param {String} url
* @param {discord.User} user
*/
-exports.tsready = (name,id,url,user) => {
+exports.tsready = (name,url,user,creator) => {
const embed = new discord.EmbedBuilder()
.setTitle("🧾 "+l.transcripts.title)
.setColor(config.color)
.setAuthor({name:user.username,iconURL:user.displayAvatarURL()})
.setFooter({text:name})
+
+ if (creator) embed.setFields([{name:"Ticket Creator", value:"<@"+creator.id+">"}])
if (url){
embed.setURL(url)
@@ -34,17 +34,19 @@ exports.beingprocessed = (name,id,rawprocesstime,user) => {
/**
*
- * @param {String} name
- * @param {String} id
- * @param {String} url
- * @param {discord.User} user
+ * @param {String} name channel name
+ * @param {String} url transcript url
+ * @param {discord.User} user transcript closer
+ * @param {discord.User} creator transcript creator
*/